#Versions and adjustments to the TeleNeo font

##V1.0 – 16.04.2020
- OTF version only

##V1.1 – 29.05.2020
- First complete package: OTF, TTF, web and variable font

##V1.2 – 14.07.2020
- Correction t' for Slovakia
- Accents for uppercase letters minimally reduced
- new: Cyrillic characters

##V1.3 – 03.09.2020
- Quotation marks without composites -> so printing on Telekom Ricoh devices from Word is also possible without problems
- Optimization Hinting Extrabold for Office font format: We have now assigned a lighter stem to the s in the hinting commands. -> Better readable on displays especially in PowerPoint.
- New systematic spaces (eighth square/ Achtelgeviert etc.)
- new: Variable font with width axis

##V1.3 – 18.09.2020
- New only variable font (TTF and Woff2)) - V1.4
Display problem with one Cyrillic character solved.
- Since only the variable font is V1.4, but the rest is still V1.3, the version number remains at V1.3 for now.

##V1.31 – 15.01.2021
- Optimization vertical alignment of web fonts for cross-browser compatibility.
- Updated only: TeleNeoWeb and TeleNeoVariableWeb

##V1.31 – 04.03.2021
- Optimization TeleNeo Office Kerning
- Optimization TeleNeo Office Installation - problems with installation on MacOS solved

##V1.31 – 03.05.2021
- Correction of vertical alignment in TeleNeoVariableWeb. The vertical alignment of the variable font is now 100% identical with the TeleNeoWeb fonts.

##V1.6 – 01.06.2021
- Addition of Greek character for all fonts including variable fonts
- Synchronisation of version numbers. All fonts now with the same version number (1.6)
- First release of TeleNeo Marker along with version V1.6 - separate download

##V1.7 – 13.07.2022
- Addition new corporate T logo .T.

##V1.8 - 19.05.2023
- New Ultra font weight integrated in TeleNeo family. Available for all characters.
- Desktop (OTF), Office (TTF), Web and variable font available
